.. _report_utils:

Tax-Brain Report Utilities
======================================

**report_utils**

taxbrain.report_utils
------------------------------------------

.. currentmodule:: taxbrain.report_utils

.. automodule:: taxbrain.report_utils
  :members: md_to_pdf, convert_table, policy_table, write_text, date,
    form_intro, form_baseline_intro, largest_tax_change, notable_changes,
    behavioral_assumptions, consumption_assumptions, growth_assumptions,
    convert_params, dollar_str_formatting
